pub struct OwnedPath { /* private fields */ }Expand description
OwnedPath is the equivalent of PathBuf in the normal std library.
It is a path whose inner representation is a String.
The path can be modified by adding other paths using the OwnedPath::push method.
Implementations
Sourceimpl OwnedPath
impl OwnedPath
pub fn as_path(&self) -> &Path
Sourcepub fn push<P: AsRef<Path>>(&mut self, segment: P)
pub fn push<P: AsRef<Path>>(&mut self, segment: P)
Appends another path to the end of this path. If the other path is absolute, but this path is not empty, then the path will be appended as a relative path.
use kstd::path::owned::OwnedPath;
let mut path = OwnedPath::from("foo");
path.push("/bar");
assert_eq!(path.to_string(), "foo/bar");Pushing a parent directory will not remove the last component of the path:
use kstd::path::owned::OwnedPath;
let mut path = OwnedPath::from("foo/bar");
path.push("..");
assert_eq!(path.to_string(), "foo/bar/..");Pushing a root dir is a no-op if the path is not empty, otherwise it will make this path absolute.
use kstd::path::owned::OwnedPath;
let mut path = OwnedPath::new();
path.push("/");
path.push("foo");
assert_eq!(path.to_string(), "/foo");Pushing a current dir is always a no-op and will not modify the path in any way.
Sourcepub fn into_components(self) -> Vec<OwnedPath>
pub fn into_components(self) -> Vec<OwnedPath>
Converts the path into its components.
use kstd::path::owned::OwnedPath;
let mut my_root = OwnedPath::from("/my/path");
assert_eq!(vec![OwnedPath::from("my"), OwnedPath::from("path")], my_root.into_components());pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn components(&self) -> Components<'_> ⓘ